@@ -2,6 +2,7 @@
 
 # Released under the MIT License.
 # Copyright, 2022-2025, by Samuel Williams.
+# Copyright, 2025, by Yasha Krasnou.
 
 require "console/compatible/logger"
 require "console/output/terminal"
@@ -43,4 +44,10 @@ describe Console::Compatible::Logger do
 		expect(logger.level).to be_a(Integer)
 		expect(logger.level).to be == ::Logger::DEBUG
 	end
+	
+	it "accepts keyword arguments and passes them to the log device" do
+		logger.add(Logger::INFO, "Hello World", request_id: 137)
+		
+		expect(stream.string).to be(:include?, '"request_id": 137')
+	end
 end
