@@ -2,7 +2,7 @@
 
 # Released under the MIT License.
 # Copyright, 2021, by Robert Schulze.
-# Copyright, 2021-2024, by Samuel Williams.
+# Copyright, 2021-2025, by Samuel Williams.
 # Copyright, 2024, by Patrik Wenger.
 
 require "console/event/failure"
@@ -15,7 +15,7 @@ class TestError < StandardError
 end
 
 describe Console::Event::Failure do
-	include_context Sus::Fixtures::Console::CapturedLogger
+	include Sus::Fixtures::Console::CapturedLogger
 	
 	with "test error" do
 		let(:error) do
@@ -53,7 +53,7 @@ describe Console::Event::Failure do
 				)
 			)
 		end
-
+		
 		it "can get #exception" do
 			failure = Console::Event::Failure.for(error)
 			
