@@ -7,7 +7,7 @@ require "sus/fixtures/console"
 require "console/warn"
 
 describe "Kernel#warn" do
-	include_context Sus::Fixtures::Console::CapturedLogger
+	include Sus::Fixtures::Console::CapturedLogger
 	
 	it "redirects to Console.warn" do
 		warn "It did not work as expected!"
